darkhistory.physics.CMB_spec — DarkHistory documentation

# darkhistory.physics.CMB_spec

`darkhistory.physics.` `CMB_spec`(eng, temp)

  CMB spectrum in number of photons cm-3 eV-1.

  The normalization used here is

  \[\frac{dN}{dE \, dV} = \frac{E^2}{\pi^2 (\hbar c)^3} \frac{1}{e^{E/T_\text{CMB}} - 1} \,,\]

  with TCMB given in eV. Returns zero if E > 500 TCMB.

  Parameters: | temp : float Temperature of the CMB in eV. eng : float or ndarray Energy of the photon in eV.
  Returns: | ndarray The number density of photons per unit energy in eV.

#### Previous topic

darkhistory.physics.CMB_eng_density

#### Next topic

darkhistory.physics.Tm_std

### This Page

Show Source